import 'dart:async';
import 'package:flutter/material.dart';
import 'package:baby_names_app/models/names.dart';
import 'package:baby_names_app/utils/dbhelper.dart';

class HomeScreen extends StatefulWidget {
  @override
  _HomeScreenState createState() => new _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen> with TickerProviderStateMixin {
  DBHelper dbHelper = DBHelper();
  final Set<Names> _saved = new Set<Names>();
  List<Names> namesList;
  int count = 0;

  final TextStyle _biggerFont =
      const TextStyle(fontFamily: "BalooThambi", fontSize: 16.0);
  final TextStyle _englishFont = const TextStyle(
    fontFamily: "BalooThambi",
    fontSize: 14.0,
    color: Colors.pink,
  );
  TextEditingController controller = new TextEditingController();

  @override
  Widget build(BuildContext context) {
    if (namesList == null) {
      namesList = List<Names>();
      updateListView();
    }

    return Scaffold(
      appBar: AppBar(
        title: Text('தமிழ் குழந்தை பெயர்கள்'),
        actions: <Widget>[
          new IconButton(
            icon: const Icon(Icons.favorite_border),
            onPressed: _pushSaved,
          ),
        ],
      ),
      body: new Container(
        margin: EdgeInsets.only(left: 10.0, right: 10.0, top: 10.0),
        child: new Column(
          children: <Widget>[_createSearchView(), _buildSuggestions()],
        ),
      ),
    );
  }

  //Create a SearchView
  Widget _createSearchView() {
    return new Container(
      child: new TextField(
        textAlign: TextAlign.center,
        controller: controller,
        onChanged: (value) {
          //filterSearchResults(value);
          debugPrint('text search');
        },
        decoration: InputDecoration(
            labelText: "தேடு",
            hintText: "முதல் எழுத்தை உள்ளீடு செய்யவும் ",
            prefixIcon: Icon(Icons.search),
            border: OutlineInputBorder(
                borderRadius: BorderRadius.all(Radius.circular(5.0)))),
      ),
    );
  }

  Widget _buildSuggestions() {
    return new Flexible(
        child: ListView.builder(
            padding: const EdgeInsets.all(16.0),
            itemCount: namesList.length,
            itemBuilder: (BuildContext _context, int position) {
              return _buildRow(namesList[position]);
            }));
  }

  Widget _buildRow(Names pair) {
    final bool alreadySaved = _saved.contains(pair);

    return new ListTile(
      title: new Text(
        pair.tamilName,
        style: _biggerFont,
      ),
      subtitle: new Text(pair.englishName.toUpperCase(), style: _englishFont),
      trailing: GestureDetector(
        child: Icon(
          Icons.share,
          color: Colors.grey,
        ),
        onTap: () {
          debugPrint("share clicked");
        },
      ),
      leading: new Icon(
        alreadySaved ? Icons.favorite : Icons.favorite_border,
        color: alreadySaved ? Colors.red : null,
      ),
      isThreeLine: true,
      onTap: () {
        setState(() {
          if (alreadySaved) {
            _saved.remove(pair);
          } else {
            _saved.add(pair);
          }
        });
      },
    );
  }

  void updateListView() {
    final dynamic dbFuture = dbHelper.initDb();
    dbFuture.then((database) {
      Future<List<Names>> noteListFuture = dbHelper.getNoteList();
      noteListFuture.then((noteList) {
        setState(() {
          this.namesList = noteList;
          this.count = noteList.length;
        });
      });
    });
  }

  void _pushSaved() {
    Navigator.of(context).push(
      new MaterialPageRoute<void>(
        builder: (BuildContext context) {
          final Iterable<ListTile> tiles = _saved.map(
            (Names pair) {
              return new ListTile(
                title: new Text(
                  pair.tamilName,
                  style: _biggerFont,
                ),
                subtitle: new Text(pair.englishName.toUpperCase(),
                    style: _englishFont),
                trailing: Icon(Icons.share),
                leading: new Icon(Icons.favorite, color: Colors.red),
                isThreeLine: true,
                onTap: () {
                  setState(() {
                    _saved.remove(pair);
                  });
                },
              );
            },
          );
          final List<Widget> divided = ListTile.divideTiles(
            context: context,
            tiles: tiles,
          ).toList();
          return new Scaffold(
            appBar: new AppBar(
              title: const Text('எனக்கு பிடித்த பெயர்கள்'),
            ),
            body: new ListView(children: divided),
          );
        },
      ),
    );
  }
}
