import 'package:sqflite/sqflite.dart';
import 'dart:async';
import 'dart:io';
import 'package:path_provider/path_provider.dart';
import 'package:baby_names_app/models/names.dart';

class DBHelper {
  static DBHelper _dbHelper; // Singleton DatabaseHelper
  static Database _db; // Singleton Database

  String namesTable = 'Names';
  String colId = 'id';
  String colGender = 'gender';
  String colReligion = 'religion';
  String colTamilName = 'tamilName';
  String colEnglishName = 'englishName';
  String colMeaning = 'meaning';
  String colLuckyNo = 'luckyNo';

  DBHelper._createInstance(); // Named constructor to create instance of DatabaseHelper

  factory DBHelper() {
    if (_dbHelper == null) {
      _dbHelper = DBHelper
          ._createInstance(); // This is executed only once, singleton object
    }
    return _dbHelper;
  }

  Future<Database> get db async {
    if (_db == null) {
      _db = await initDb();
    }
    return _db;
  }

  Future<Database> initDb() async {
    // Get the directory path for both Android and iOS to store database.
    Directory directory = await getApplicationDocumentsDirectory();
    String path = directory.path + '/baby_names.db';

    var theDb = await openDatabase(path, version: 1, onCreate: _onCreate);
    return theDb;
  }

  // Creating a table name Employee with fields
  void _onCreate(Database db, int version) async {
    // When creating the db, create the table
    await db.execute(
        "CREATE TABLE Names(id INTEGER PRIMARY KEY, englishName TEXT, gender TEXT,  meaning TEXT, tamilName TEXT)");
    print("Created tables");
  }

  // Fetch Operation: Get all note objects from database
  Future<List<Map<String, dynamic>>> getNoteMapList() async {
    Database db = await this.db;

//		var result = await db.rawQuery('SELECT * FROM $noteTable order by $colPriority ASC');
    var result = await db.query(namesTable, orderBy: '$colEnglishName ASC');
    return result;
  }

  // Get number of Note objects in database
  Future<int> getCount() async {
    Database db = await this.db;
    List<Map<String, dynamic>> x =
        await db.rawQuery('SELECT COUNT (*) from $namesTable');
    int result = Sqflite.firstIntValue(x);
    return result;
  }

  // Get the 'Map List' [ List<Map> ] and convert it to 'Note List' [ List<Note> ]
  Future<List<Names>> getNoteList() async {
    var noteMapList = await getNoteMapList(); // Get 'Map List' from database
    int count =
        noteMapList.length; // Count the number of map entries in db table

    List<Names> noteList = List<Names>();
    // For loop to create a 'Note List' from a 'Map List'
    for (int i = 0; i < count; i++) {
      noteList.add(Names.fromMapObject(noteMapList[i]));
    }

    return noteList;
  }
}
